@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: scientific
-version: 0.3.4.4
-id: scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
-key: scien_AqBmwDfwK7K24A70hu3AxF
+version: 0.3.4.6
+id: scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
+key: scien_1OnQq6NJ9k3LnQc0gkGZFN
 license: BSD3
 maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
 homepage: https://github.com/basvandijk/scientific
@@ -47,10 +47,10 @@ exposed-modules:
 hidden-modules: Math.NumberTheory.Logarithms
                 GHC.Integer.Logarithms.Compat GHC.Integer.Compat Utils
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/scientific-0.3.4.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/scientific-0.3.4.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/scientific-0.3.4.4
-hs-libraries: HSscientific-0.3.4.4-AqBmwDfwK7K24A70hu3AxF
+import-dirs: /usr/lib/ghc-7.10.3/site-local/scientific-0.3.4.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/scientific-0.3.4.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/scientific-0.3.4.6
+hs-libraries: HSscientific-0.3.4.6-1OnQq6NJ9k3LnQc0gkGZFN
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
